@@ -10,6 +10,7 @@ from roman_datamodels.testing import utils as testutil
 
 __all__ = ["DQInitStep"]
 
+
 class DQInitStep(RomanStep):
     """Initialize the Data Quality extension from the
     mask reference file.
@@ -22,7 +23,6 @@ class DQInitStep(RomanStep):
     input model.
     """
 
-
     reference_file_types = ['mask']
 
     def process(self, input):
@@ -50,9 +50,9 @@ class DQInitStep(RomanStep):
             for key in input_model.keys():
                 # If a dictionary (like meta), overwrite entires (but keep
                 # required dummy entries that may not be in input_model)
-                if isinstance(input_ramp[key],dict):
+                if isinstance(input_ramp[key], dict):
                     input_ramp[key].update(input_model.__getattr__(key))
-                elif isinstance(input_ramp[key],np.ndarray):
+                elif isinstance(input_ramp[key], np.ndarray):
                     # Cast input ndarray as RampModel dtype
                     input_ramp[key] = input_model.__getattr__(key).astype(input_ramp[key].dtype)
                 else:
@@ -63,24 +63,20 @@ class DQInitStep(RomanStep):
         else:
             init_model = input_model
 
-        # Get reference file paths
-        reference_file_names = {}
-        reffile = self.get_reference_file(init_model, "mask")
-        reference_file_names['mask'] = reffile if reffile != 'N/A' else None
+        # Get reference file path
+        reference_file_name = self.get_reference_file(init_model, "mask")
 
-        # Open the relevant reference files as datamodels
-        reference_file_models = {}
-
-        # Test for reference files
-        if reffile is not None:
+        # Test for reference file
+        if reference_file_name is not None:
             # If there are mask files, perform dq step
-            reference_file_models['mask'] = rdm.open(reffile)
-            self.log.debug(f'Using MASK ref file: {reffile}')
+            # Open the relevant reference files as datamodels
+            reference_file_model = rdm.open(reference_file_name)
+            self.log.debug(f'Using MASK ref file: {reference_file_name}')
 
             # Apply the DQ step
             output_model = dq_initialization.do_dqinit(
                 init_model,
-                **reference_file_models,
+                reference_file_model,
             )
 
             # copy original border reference file arrays (data and dq)
@@ -100,7 +96,7 @@ class DQInitStep(RomanStep):
 
         else:
             # Skip DQ step if no mask files
-            reference_file_models['mask'] = None
+            reference_file_model = None
             self.log.warning('No MASK reference file found.')
             self.log.warning('DQ initialization step will be skipped.')
 
@@ -112,9 +108,14 @@ class DQInitStep(RomanStep):
         input_model.close()
         init_model.close()
         try:
-            for model in reference_file_models.values():
-                model.close()
+            reference_file_model.close()
         except AttributeError:
             pass
 
+        if self.save_results:
+            try:
+                self.suffix = 'dqinit'
+            except AttributeError:
+                self['suffix'] = 'dqinit'
+
         return output_model
