@@ -10,7 +10,7 @@ def test_jump_detection_step(rtdata, ignore_asdf_paths):
     """ Function to run and compare Jump Detection files. Note: This should
         include tests for overrides etc. """
 
-    input_file = "r0000101001001001001_01101_0001_WFI01_darkcurrentstep.asdf"
+    input_file = "r0000101001001001001_01101_0001_WFI01_darkcurrent.asdf"
     rtdata.get_data(f"WFI/image/{input_file}")
     rtdata.input = input_file
 
@@ -21,7 +21,7 @@ def test_jump_detection_step(rtdata, ignore_asdf_paths):
             '--three_group_rejection_threshold=185.',
             '--four_group_rejection_threshold=190.']
     RomanStep.from_cmdline(args)
-    output = "r0000101001001001001_01101_0001_WFI01_jumpstep.asdf"
+    output = "r0000101001001001001_01101_0001_WFI01_jump.asdf"
     rtdata.output = output
     rtdata.get_truth(f"truth/WFI/image/{output}")
     assert (compare_asdf(rtdata.output, rtdata.truth,
