@@ -7,6 +7,7 @@ from .dq_init.dq_init_step import DQInitStep
 from .flatfield.flat_field_step import FlatFieldStep
 from .jump.jump_step import JumpStep
 from .linearity.linearity_step import LinearityStep
+from .photom.photom_step import PhotomStep
 from .ramp_fitting.ramp_fit_step import RampFitStep
 from .saturation.saturation_step import SaturationStep
 from .assign_wcs.assign_wcs_step import AssignWcsStep
@@ -18,6 +19,7 @@ __all__ = [
     "FlatFieldStep",
     "JumpStep",
     "LinearityStep",
+    "PhotomStep",
     "RampFitStep",
     "SaturationStep",
     "AssignWcsStep",
